<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Entity;

use Sylius\Component\Resource\Model\AbstractTranslation;
use Symfony\Component\Validator\Constraints as Assert;

abstract class AbstractReferableTranslation extends AbstractTranslation
{
    protected bool $enabled = false;

    protected bool $indexable = true;

    /** @Assert\Length(max="255", groups={"default", "sylius"}) */
    protected ?string $metadataTitle = null;

    /**
     * @Assert\Length(max="255", groups={"default", "sylius"})
     * @Assert\Url(groups={"default", "sylius"})
     */
    protected ?string $metadataUrl = null;

    /**
     * @Assert\Length(max="255", groups={"default", "sylius"})
     * @Assert\Url(groups={"default", "sylius"})
     */
    protected ?string $metadataImage = null;

    /** @Assert\Length(max="255", groups={"default", "sylius"}) */
    protected ?string $metadataDescription = null;

    /** @Assert\Length(max="255", groups={"default", "sylius"}) */
    protected ?string $type = null;

    public function isEnabled(): bool
    {
        return $this->enabled;
    }

    public function setEnabled(bool $enabled): self
    {
        $this->enabled = $enabled;

        return $this;
    }

    public function isIndexable(): bool
    {
        return $this->indexable;
    }

    public function setIndexable(bool $indexable): self
    {
        $this->indexable = $indexable;

        return $this;
    }

    public function getMetadataTitle(): ?string
    {
        return $this->metadataTitle;
    }

    public function setMetadataTitle(?string $title): self
    {
        $this->metadataTitle = $title;

        return $this;
    }

    public function getMetadataUrl(): ?string
    {
        return $this->metadataUrl;
    }

    public function setMetadataUrl(?string $url): self
    {
        $this->metadataUrl = $url;

        return $this;
    }

    public function getMetadataType(): ?string
    {
        return $this->type;
    }

    public function setMetadataType(?string $type): self
    {
        $this->type = $type;

        return $this;
    }

    public function getMetadataDescription(): ?string
    {
        return $this->metadataDescription;
    }

    public function setMetadataDescription(?string $description): self
    {
        $this->metadataDescription = $description;

        return $this;
    }

    public function getMetadataImage(): ?string
    {
        return $this->metadataImage;
    }

    public function setMetadataImage(?string $url): self
    {
        $this->metadataImage = $url;

        return $this;
    }
}
