<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Form;

use Dedi\SyliusBlogPlugin\Entity\Category;
use Sylius\Bundle\ChannelBundle\Form\Type\ChannelChoiceType;
use Sylius\Bundle\ResourceBundle\Form\Type\AbstractResourceType;
use Sylius\Bundle\ResourceBundle\Form\Type\ResourceTranslationsType;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints\Valid;

class CategoryType extends AbstractResourceType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('enabled', CheckboxType::class, [
                'label' => 'dedi_blog.form.enabled',
            ])
            ->add('position', NumberType::class, [
                'html5' => true,
                'attr' => ['min' => 0, 'step' => 1],
                'label' => 'dedi_blog.form.category.position',
            ])
            ->add('channels', ChannelChoiceType::class, [
                'multiple' => true,
                'expanded' => true,
                'label' => 'dedi_blog.form.channels',
            ])
            ->add('translations', ResourceTranslationsType::class, [
                'entry_type' => CategoryTranslationType::class,
                'constraints' => [new Valid()],
            ])
            /*->add('subCategories', CategoryAutocompleteChoiceType::class, [
                'multiple' => true,
                'label' => 'sylius.ui.categories',
                'required' => false,
            ])*/
            ->add('subCategories', EntityType::class, [
                'class' => Category::class,
                'multiple' => true,
                'choice_name' => 'name',
                'choice_value' => 'id',
                'required' => false,
                'label' => 'dedi_blog.form.category.sub_categories',
            ])
        ;
    }
}
